import type { ContentProtectionError } from 'theoplayer';
import type { TitaniumDrmConfiguration } from './TitaniumDrmConfiguration';
import type { DeviceBasedTitaniumIntegrationParameters } from './TitaniumIntegrationParameters';
export interface TitaniumDeviceAuthorizationData {
    LatensRegistration: TitaniumLatensRegistration;
}
export interface TitaniumLatensRegistration {
    CustomerName: string;
    AccountName: string;
    PortalId: string;
    FriendlyName: string;
    AppVersion: string | undefined;
    DeviceInfo: TitaniumDeviceInfo;
}
export interface TitaniumDeviceInfo extends TitaniumCDMDescription {
    FormatVersion: string;
    DeviceType: string;
    OSType: string;
    OSVersion: string;
    DeviceVendor: string;
    DeviceModel: string;
}
export interface TitaniumCDMDescription {
    DRMProvider: string;
    DRMVersion: string;
    DRMType: string;
}
export declare enum TitaniumCDMType {
    WIDEVINE = "Widevine",
    PLAYREADY = "PlayreadyV2",
    PLAYREADY_v2 = "PlayreadyV2",
    PLAYREADY_v3 = "PlayreadyV3",
    FAIRPLAY = "Fairplay"
}
export declare const TITANIUM_CDM_DESCRIPTIONS: {
    [cdmType: string]: TitaniumCDMDescription;
};
export declare const getTitaniumDeviceAuthorizationData: (integrationParameters: DeviceBasedTitaniumIntegrationParameters, cdmType: TitaniumCDMType) => TitaniumDeviceAuthorizationData;
export declare const createErrorForMalformedDeviceInfoConfiguration: (configuration: TitaniumDrmConfiguration, cdmType: TitaniumCDMType) => ContentProtectionError;
export declare const createErrorForMalformedTokenConfiguration: (configuration: TitaniumDrmConfiguration, cdmType: TitaniumCDMType) => ContentProtectionError;
export declare const createTitaniumAuthHeader: (configuration: TitaniumDrmConfiguration, cdmType: TitaniumCDMType) => string;
export declare const createTitaniumDeviceHeader: (configuration: TitaniumDrmConfiguration, cdmType: TitaniumCDMType) => string;
export declare const createTitaniumHeaders: (configuration: TitaniumDrmConfiguration, cdmType: TitaniumCDMType) => {
    [key: string]: string;
};
